ShortKitCarouselOverlayBuilder typedef

ShortKitCarouselOverlayBuilder = Widget Function(BuildContext context, ImageCarouselItem item, bool isActive, int activeImageIndex)

Builder for image carousel overlay widgets.

isActive is true when this carousel cell is the active (on-screen) cell. activeImageIndex is the zero-based index of the currently active image in the carousel, updated in real time as the user swipes.

Implementation

typedef ShortKitCarouselOverlayBuilder = Widget Function(
  BuildContext context,
  ImageCarouselItem item,
  bool isActive,
  int activeImageIndex,
);